@@ -901,6 +901,7 @@ def test_interface_subclass():
         def method_b(self):
             pass
 
+    # expected to fail since it's missing method_b
     with pytest.raises(InvalidImplementation) as exc:
 
         class JustA(implements(AandB)):  # pragma: nocover
@@ -917,6 +918,7 @@ def test_interface_subclass():
     )
     assert actual_message == expected_message
 
+    # expected to fail since it's missing method_a
     with pytest.raises(InvalidImplementation) as exc:
 
         class JustB(implements(AandB)):  # pragma: nocover
@@ -933,6 +935,12 @@ def test_interface_subclass():
     )
     assert actual_message == expected_message
 
+    # expected to pass since interface A only requires method_a
+    class JustA2(implements(A)):  # pragma: nocover
+        def method_a(self):
+            pass
+
+    # expected to pass since it implements both methods
     class Both(implements(AandB)):  # pragma: nocover
         def method_a(self):
             pass
@@ -950,6 +958,7 @@ def test_subclass_conflict_with_different_parents():
         def method_b(self):
             pass
 
+    # expected to fail since method_a has different signature in interface A
     with pytest.raises(TypeError) as exc:
 
         class C1(A):  # pragma: nocover
@@ -964,9 +973,10 @@ def test_subclass_conflict_with_different_parents():
     )
     assert actual_message == expected_message
 
+    # expected to fail since method_b has different signature in interface B
     with pytest.raises(TypeError) as exc:
 
-        class C2(A):  # pragma: nocover
+        class C2(B):  # pragma: nocover
             def method_b(self, y, z=None):
                 pass
 
@@ -978,6 +988,11 @@ def test_subclass_conflict_with_different_parents():
     )
     assert actual_message == expected_message
 
+    # expected to pass since method_b does not exist in interface A
+    class C3(A):  # pragma: nocover
+        def method_b(self, y, z=None):
+            pass
+
 
 def test_subclass_allow_compatible_extension():
     class A(Interface):  # pragma: nocover
